Welcome to gmsh_interop's documentation!
========================================

This package allows Python to interoperate with the `gmsh <http://gmsh.info/>`_
mesh generator.

This package contains:

* :mod:`gmsh_interop.reader` to read gmsh's ``.msh`` file format.
* :mod:`gmsh_interop.runner` to run gmsh under program control and process its output.

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    reader
    runner
    misc
    🚀 Github <https://github.com/inducer/gmsh_interop>
    💾 Download Releases <https://pypi.org/project/gmsh_interop>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
